#include <avr/io.h>
#include <avr/interrupt.h>
#include <Servo.h>

#define PWM_PIN 9
#define ALARM_FREQUENCY 2000
#define ALARM_DUTY_CYCLE 128

Servo servo;
int angle = 10;
int led = 13;
int digitalPin = 2;
int analogPin = A5;
int digitalVal;
int analogVal;
int data = 1;
const int buttonPin = 7;

int buttonState = 0;

void setPWMFrequency(unsigned int frequency) {
  unsigned int prescaler = F_CPU / (frequency * 256) - 1;
  TCCR1B = (TCCR1B & 0xF8) | (prescaler & 0x07);
}

void setupPWM() {
  TCCR1A = (1 << COM1A1) | (1 << WGM10);
  TCCR1B = (1 << WGM12) | (1 << CS10);
  OCR1A = 0;
}

void playAlarmSound() {
  setPWMFrequency(ALARM_FREQUENCY);
  OCR1A = ALARM_DUTY_CYCLE;
}

void stopAlarmSound() {
  OCR1A = 0;
}

void setup() {
  Serial.begin(19200);
  servo.attach(8);
  servo.write(angle);

  pinMode(PWM_PIN, OUTPUT);
  pinMode(led, OUTPUT);
  pinMode(digitalPin, INPUT);
  pinMode(buttonPin, INPUT);
  setupPWM();
}

void openDoor() {
  for(int angle1 = 0; angle1 < 500 && angle < 720; angle1++)  
  {                               
    angle += angle1;   
    servo.write(angle);    
    delay(15);                   
  }
}

void loop() {
  
  digitalVal = digitalRead(digitalPin); 
  delay(1500);

  if (digitalVal == HIGH) { // Flame is detected
    if(data != 0) {
      Serial.println("Fire");
    }
    data = 0;
    playAlarmSound();
    digitalWrite(led, HIGH); // Turn on Arduino's LED
    
  } else {
    digitalWrite(led, LOW); // Turn off Arduino's LED
  }
  
  if(data == 0) {
    openDoor();
  }

  buttonState = digitalRead(buttonPin);
  if(buttonState == HIGH) {
    data = 1;
    Serial.println(data);
    stopAlarmSound();
  }
  analogVal = analogRead(analogPin);
  delay(100);
}